==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrStringArrayBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class JSONSchemaPropsOrStringArrayBuilder extends JSONSchemaPropsOrStringArrayFluentImpl<JSONSchemaPropsOrStringArrayBuilder> implements VisitableBuilder<JSONSchemaPropsOrStringArray,JSONSchemaPropsOrStringArrayBuilder>{
  public JSONSchemaPropsOrStringArrayBuilder() {
    this(false);
  }
  public JSONSchemaPropsOrStringArrayBuilder(Boolean validationEnabled) {
    this(new JSONSchemaPropsOrStringArray(), validationEnabled);
  }
  public JSONSchemaPropsOrStringArrayBuilder(JSONSchemaPropsOrStringArrayFluent<?> fluent) {
    this(fluent, false);
  }
  public JSONSchemaPropsOrStringArrayBuilder(JSONSchemaPropsOrStringArrayFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new JSONSchemaPropsOrStringArray(), validationEnabled);
  }
  public JSONSchemaPropsOrStringArrayBuilder(JSONSchemaPropsOrStringArrayFluent<?> fluent,JSONSchemaPropsOrStringArray instance) {
    this(fluent, instance, false);
  }
  public JSONSchemaPropsOrStringArrayBuilder(JSONSchemaPropsOrStringArrayFluent<?> fluent,JSONSchemaPropsOrStringArray instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withProperty(instance.getProperty());
      fluent.withSchema(instance.getSchema());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public JSONSchemaPropsOrStringArrayBuilder(JSONSchemaPropsOrStringArray instance) {
    this(instance,false);
  }
  public JSONSchemaPropsOrStringArrayBuilder(JSONSchemaPropsOrStringArray instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withProperty(instance.getProperty());
      this.withSchema(instance.getSchema());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  JSONSchemaPropsOrStringArrayFluent<?> fluent;
  Boolean validationEnabled;
  public JSONSchemaPropsOrStringArray build() {
    JSONSchemaPropsOrStringArray buildable = new JSONSchemaPropsOrStringArray(fluent.getProperty(),fluent.getSchema());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-apiextensions-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrStringArrayBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class JSONSchemaPropsOrStringArrayBuilder extends JSONSchemaPropsOrStringArrayFluent<JSONSchemaPropsOrStringArrayBuilder> implements VisitableBuilder<JSONSchemaPropsOrStringArray,JSONSchemaPropsOrStringArrayBuilder>{
  public JSONSchemaPropsOrStringArrayBuilder() {
    this(false);
  }
  public JSONSchemaPropsOrStringArrayBuilder(Boolean validationEnabled) {
    this(new JSONSchemaPropsOrStringArray(), validationEnabled);
  }
  public JSONSchemaPropsOrStringArrayBuilder(JSONSchemaPropsOrStringArrayFluent<?> fluent) {
    this(fluent, false);
  }
  public JSONSchemaPropsOrStringArrayBuilder(JSONSchemaPropsOrStringArrayFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new JSONSchemaPropsOrStringArray(), validationEnabled);
  }
  public JSONSchemaPropsOrStringArrayBuilder(JSONSchemaPropsOrStringArrayFluent<?> fluent,JSONSchemaPropsOrStringArray instance) {
    this(fluent, instance, false);
  }
  public JSONSchemaPropsOrStringArrayBuilder(JSONSchemaPropsOrStringArrayFluent<?> fluent,JSONSchemaPropsOrStringArray instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new JSONSchemaPropsOrStringArray());

    if (instance != null) {
      fluent.withProperty(instance.getProperty());
      fluent.withSchema(instance.getSchema());
      fluent.withProperty(instance.getProperty());
      fluent.withSchema(instance.getSchema());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public JSONSchemaPropsOrStringArrayBuilder(JSONSchemaPropsOrStringArray instance) {
    this(instance,false);
  }
  public JSONSchemaPropsOrStringArrayBuilder(JSONSchemaPropsOrStringArray instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new JSONSchemaPropsOrStringArray());

    if (instance != null) {
      this.withProperty(instance.getProperty());
      this.withSchema(instance.getSchema());
      this.withProperty(instance.getProperty());
      this.withSchema(instance.getSchema());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  JSONSchemaPropsOrStringArrayFluent<?> fluent;
  Boolean validationEnabled;
  public JSONSchemaPropsOrStringArray build() {
    JSONSchemaPropsOrStringArray buildable = new JSONSchemaPropsOrStringArray(fluent.getProperty(),fluent.buildSchema());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
